package emuProfIILoRaCfg1

// provisioning device with
// f_port=1: 01 00 0A 0B 0C 0D 0E 17 18 19 F0 4C
// f_port=2: 01 00 0A 24 26 28 2A 7A


import (
  "fmt"
  "encoding/json"
  "udi/database"
)

type emuVariable struct {
  Value interface{} `json:"value"`
  Unit string `json:"unit"`
}

/*
    {
      "Active Energy Export T1 64bit": {
        "unit": "Wh",
        "value": 0
      },
      "Active Energy Import T1 64bit": {
        "unit": "Wh",
        "value": 0
      },
      "Reactive Energy Export T1 64bit": {
        "unit": "varh",
        "value": 0
      },
      "Reactive Energy Import T1 64bit": {
        "unit": "varh",
        "value": 0
      },
      "medium": {
        "desc": "Electricity",
        "type": 1
      },
      "timeStamp": 1702052100
    }
*/
type emuMessage1 struct {
  ActiveEnergyExport emuVariable `json:"Active Energy Export T1 64bit"`
  ReactiveEnergyExport emuVariable `json:"Reactive Energy Export T1 64bit"`
  ActiveEnergyImport emuVariable `json:"Active Energy Import T1 64bit"`
  ReactiveEnergyImport emuVariable `json:"Reactive Energy Import T1 64bit"`
  Medium struct {
    Desc string `json:"desc"`
    Type string `json:"type"`
  } `json:"medium"`
  Timestamp int `json:"timestamp"`
}

func Parse(fPort int, decodedPayload map[string]interface{}) (map[string]database.VariableType, error) {
  switch fPort {
  case 1:
    var emuMessage1 emuMessage1
    err := json.Unmarshal([]byte(decodedPayload), &emuMessage1)
    if err != nil {
      return nil, fmt.Errorf("Unable to parse payload, fPort %d", fPort)
    }
    variables := make(map[string]database.VariableType)
    variables["ActiveEnergyExport"] = database.VariableType { 
      Variable: "ActiveEnergyExport", 
      Unit: emuMessage1.ActiveEnergyExport.Unit,
      Value: emuMessage1.ActiveEnergyExport.Value,
    }
    variables["ActiveEnergyImport"] = database.VariableType { 
      Variable: "ActiveEnergyImport", 
      Unit: emuMessage1.ActiveEnergyImport.Unit,
      Value: emuMessage1.ActiveEnergyImport.Value,
    }
    variables["ReactiveEnergyExport"] = database.VariableType { 
      Variable: "ReactiveEnergyExport", 
      Unit: emuMessage1.ReactiveEnergyExport.Unit,
      Value: emuMessage1.ReactiveEnergyExport.Value,
    }
    variables["ReactiveEnergyImport"] = database.VariableType { 
      Variable: "ReactiveEnergyImport", 
      Unit: emuMessage1.ReactiveEnergyImport.Unit,
      Value: emuMessage1.ReactiveEnergyImport.Value,
    }
    return variables, nil
  default:
    return nil, fmt.Errorf("Unexpected fPort %d", fPort)
  }
}

